.. mi-module-zoo documentation master file, created by
   sphinx-quickstart on Fri Oct 15 15:33:04 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

mi-module-zoo
=========================================

This package contains implementations standalone, commonly reusable
standalone PyTorch ``nn.Module`` classes.

This library is maintained by the `Machine Intelligence group <https://www.microsoft.com/en-us/research/theme/machine-intelligence/>`_
in Microsoft Research.

To install it run ``pip install mi-module-zoo``.

Modules and Utilities
---------------------
.. toctree::
   :maxdepth: 2

   modules/relationaltransformer
   modules/relationalmha
   modules/settransformers
   modules/utils



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
